@@ -23,6 +23,13 @@
         <translation>系統升級前需要為您備份，請耐心等待</translation>
     </message>
 </context>
+<context>
+    <name>BorderRadiusHeaderView</name>
+    <message>
+        <source>All</source>
+        <translation>全選</translation>
+    </message>
+</context>
 <context>
     <name>CheckImageResultWidget</name>
     <message>
@@ -92,11 +99,11 @@
     </message>
     <message>
         <source>Authorization status</source>
-        <translation>系統啟動狀態</translation>
+        <translation>系統激活狀態</translation>
     </message>
     <message>
         <source>Requirement: Activated</source>
-        <translation>基線要求：啟動</translation>
+        <translation>基線要求：激活</translation>
     </message>
     <message>
         <source>CPU architecture</source>
@@ -124,11 +131,11 @@
     </message>
     <message>
         <source>Activated</source>
-        <translation>已啟動</translation>
+        <translation>已激活</translation>
     </message>
     <message>
         <source>Unactivated</source>
-        <translation>未啟動</translation>
+        <translation>未激活</translation>
     </message>
     <message>
         <source>Requirement: %1 GB</source>
@@ -147,7 +154,7 @@
     <name>DBusWorker</name>
     <message>
         <source>Backup failed</source>
-        <translation type="unfinished">備份失敗</translation>
+        <translation>備份失敗</translation>
     </message>
     <message>
         <source>Upgrade failed</source>
@@ -155,7 +162,7 @@
     </message>
     <message>
         <source>Restoration failed</source>
-        <translation type="unfinished">還原失敗</translation>
+        <translation>還原失敗</translation>
     </message>
 </context>
 <context>
@@ -208,7 +215,7 @@
     </message>
     <message>
         <source>Errors:</source>
-        <translation>錯誤訊息：</translation>
+        <translation>錯誤信息：</translation>
     </message>
     <message>
         <source>Error code:</source>
@@ -216,7 +223,7 @@
     </message>
     <message>
         <source>Failed to connect to the server. Please check your network connection or select a local V23 image file.</source>
-        <translation>無法連接伺服器！請檢查網絡連接或者選擇本地V23鏡像文件</translation>
+        <translation>無法連接服務器！請檢查網絡連接或者選擇本地V23鏡像文件</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -240,18 +247,18 @@
     </message>
     <message>
         <source>Do you want to exit software evaluation?</source>
-        <translation type="unfinished">確定退出軟件評估嗎？</translation>
+        <translation>確定退出軟件評估嗎？</translation>
     </message>
     <message>
         <source>Software evaluation failed</source>
-        <translation type="unfinished">軟件評估失敗</translation>
+        <translation>軟件評估失敗</translation>
     </message>
 </context>
 <context>
     <name>InitialWidget</name>
     <message>
         <source>Deepin Upgrade</source>
-        <translation>Deepin系統升級</translation>
+        <translation type="vanished">Deepin系統升級</translation>
     </message>
     <message>
         <source>Current version: V%1</source>
@@ -263,14 +270,14 @@
     </message>
     <message>
         <source>Deepin 23</source>
-        <translation>Deepin 23</translation>
+        <translation type="vanished">Deepin 23</translation>
     </message>
     <message>
-        <source>I have read and agreed to the</source>
-        <translation type="vanished">我已閱讀並同意</translation>
+        <source>I have read and agreed to the </source>
+        <translation type="vanished">我已閲讀並同意</translation>
     </message>
     <message>
-        <source>《Deepin系统升级工具》</source>
+        <source>《Deepin系統升級工具》</source>
         <translation type="vanished">《Deepin系統升級工具》</translation>
     </message>
     <message>
@@ -291,31 +298,36 @@
     </message>
     <message>
         <source>End User License Agreement for Deepin Upgrade Tool</source>
-        <translation>Deepin 系統升級工具軟體最終用戶許可協議</translation>
+        <translatorcomment>標題</translatorcomment>
+        <translation>Deepin系統升級工具軟件最終用户許可協議</translation>
     </message>
     <message>
         <source>:/text/end_user_license_en.txt</source>
-        <translation>:/text/end_user_license_zh_HK.txt</translation>
+        <translation>:/text/end_user_license_zh_CN.txt</translation>
     </message>
     <message>
         <source>Privacy Protection Guide for Deepin Upgrade Tool</source>
-        <translation>Deepin 系統升級工具軟體隱私保護指引</translation>
+        <translatorcomment>標題</translatorcomment>
+        <translation>Deepin系統升級工具軟件隱私保護指引</translation>
     </message>
     <message>
         <source>:/text/privacy_protection_guide_en.txt</source>
-        <translation>:/text/privacy_protection_guide_zh_HK.txt</translation>
+        <translation>:/text/privacy_protection_guide_zh_CN.txt</translation>
     </message>
     <message>
         <source>End User License Agreement for Deepin Upgrade Tool.</source>
-        <translation type="vanished">《Deepin 系統升級工具軟體最終用戶許可協議》。</translation>
+        <translatorcomment>用户協議標籤名</translatorcomment>
+        <translation type="vanished">《Deepin系統升級工具軟件最終用户許可協議》。</translation>
     </message>
     <message>
         <source>Privacy Protection Guide for Deepin Upgrade Tool.</source>
-        <translation type="vanished">《Deepin 系統升級工具軟體隱私保護指引》。</translation>
+        <translatorcomment>隱私標籤名</translatorcomment>
+        <translation type="vanished">《Deepin系統升級工具軟件隱私保護指引》。</translation>
     </message>
     <message>
         <source>&quot;End User License Agreement for Deepin Upgrade Tool&quot;</source>
-        <translation>《最終用戶許可協議》</translation>
+        <translatorcomment>勾選框文字標題。</translatorcomment>
+        <translation>《最終用户許可協議》</translation>
     </message>
     <message>
         <source>&quot;Privacy Protection Guide&quot;</source>
@@ -323,7 +335,15 @@
     </message>
     <message>
         <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
-        <translation>我已閱讀並同意&lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt;和&lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;。</translation>
+        <translation>我已閲讀並同意&lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt;和&lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;。</translation>
+    </message>
+    <message>
+        <source>System Upgrade Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>deepin 23</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -345,7 +365,7 @@
     <name>MigrateFinishedWidget</name>
     <message>
         <source>App migration successful</source>
-        <translation type="unfinished">應用遷移成功</translation>
+        <translation>應用遷移成功</translation>
     </message>
     <message>
         <source>OK</source>
@@ -356,30 +376,30 @@
     <name>MigrateProgressWidget</name>
     <message>
         <source>Migrating apps</source>
-        <translation type="unfinished">應用遷移中</translation>
+        <translation>應用遷移中</translation>
     </message>
     <message>
         <source>Migrating apps, please wait patiently</source>
-        <translation type="unfinished">應用遷移中，請耐心等候</translation>
+        <translation>應用遷移中，請耐心等候</translation>
     </message>
     <message>
         <source>Reconnect</source>
-        <translation type="unfinished">重新連接</translation>
+        <translation>重新連接</translation>
     </message>
     <message>
         <source>Network error. App migration has been interrupted.</source>
-        <translation type="unfinished">網絡異常，應用遷移已中斷</translation>
+        <translation>網絡異常，應用遷移已中斷</translation>
     </message>
     <message>
         <source>Network connection failed. Please check your network.</source>
-        <translation type="unfinished">連接不到網絡，請檢查您的網絡</translation>
+        <translation>連接不到網絡，請檢查您的網絡</translation>
     </message>
 </context>
 <context>
     <name>MigrateWidget</name>
     <message>
         <source>App migration failed</source>
-        <translation type="unfinished">應用遷移失敗</translation>
+        <translation>應用遷移失敗</translation>
     </message>
     <message>
         <source>Exit</source>
@@ -451,26 +471,37 @@
     </message>
     <message>
         <source>Software Evaluation</source>
-        <translation type="unfinished">軟件評估</translation>
+        <translation>軟件評估</translation>
     </message>
     <message>
         <source>Evaluate the compatibility of installed apps in the new system</source>
-        <translation type="unfinished">評估已安裝軟件在新系統中的兼容性</translation>
+        <translation>評估已安裝軟件在新系統中的兼容性</translation>
+    </message>
+</context>
+<context>
+    <name>SoftwareEvaluationOfflineWidget</name>
+    <message>
+        <source>Software Evaluation</source>
+        <translation>軟件評估</translation>
+    </message>
+    <message>
+        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
+        <translation>您當前的使用場景處於無網絡狀態，我們無法對你正在使用的軟件進行評估，升級完成後您當前所安裝的軟件需要重新進行安裝，如需查看升級可安裝應用詳情請聯網升級</translation>
     </message>
 </context>
 <context>
     <name>SoftwareEvaluationWidget</name>
     <message>
         <source>Compatible</source>
-        <translation type="obsolete">兼容</translation>
+        <translation type="vanished">兼容</translation>
     </message>
     <message>
         <source>Incompatible</source>
-        <translation type="obsolete">不兼容</translation>
+        <translation type="vanished">不兼容</translation>
     </message>
     <message>
         <source>Evaluation Result</source>
-        <translation type="unfinished">軟件評估結果</translation>
+        <translation>軟件評估結果</translation>
     </message>
     <message>
         <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
@@ -478,11 +509,31 @@
     </message>
     <message>
         <source>Compatible Apps</source>
-        <translation type="unfinished">兼容應用</translation>
+        <translation>兼容應用</translation>
     </message>
     <message>
         <source>Incompatible Apps</source>
-        <translation type="unfinished">不兼容應用</translation>
+        <translation>不兼容應用</translation>
+    </message>
+    <message>
+        <source>V23 version supports applications</source>
+        <translation type="vanished">V23版本支持應用</translation>
+    </message>
+    <message>
+        <source>The V23 version does not support the application</source>
+        <translation type="vanished">V23版本不支持應用</translation>
+    </message>
+    <message>
+        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
+        <translation>系統升級會保證用户數據的完整性，我們不會對用户數據進行刪減</translation>
+    </message>
+    <message>
+        <source>By default, the cross-version upgrade does not migrate the installed applications. After the upgrade is completed, the system will automatically install the selected applications in the list. Please select the software that needs to be installed after the upgrade is complete</source>
+        <translation type="vanished">跨版本升級默認不對已安裝應用進行遷移，完成升級後系統會對列表勾選應用進行自動化安裝，請選擇升級完成後需要安裝的應用</translation>
+    </message>
+    <message>
+        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
+        <translation>跨版本升級不對應用進行遷移，升級完成後支持對已勾選兼容應用自動化安裝</translation>
     </message>
 </context>
 <context>
@@ -521,11 +572,11 @@
     </message>
     <message>
         <source>System backup only, no app backup</source>
-        <translation>僅備份系統，不備份應用</translation>
+        <translation type="vanished">僅備份系統，不備份應用</translation>
     </message>
     <message>
         <source>Less disk space is required if enabled, but some apps may not work properly after restoring the system from version 23.</source>
-        <translation>開啟此功能將降低備份空間要求，但從V23還原至當前系統時，部分應用可能不可用</translation>
+        <translation type="vanished">開啟此功能將降低備份空間要求，但從V23還原至當前系統時，部分應用可能不可用</translation>
     </message>
 </context>
 <context>
@@ -544,11 +595,19 @@
     </message>
     <message>
         <source>Backup failed</source>
-        <translation type="unfinished">備份失敗</translation>
+        <translation>備份失敗</translation>
     </message>
     <message>
         <source>Restoration failed</source>
-        <translation type="unfinished">還原失敗</translation>
+        <translation>還原失敗</translation>
+    </message>
+    <message>
+        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
+        <translation>點擊重啟後系統將進行升級，確認前請對當前運行應用數據進行保存</translation>
+    </message>
+    <message>
+        <source>Restart now</source>
+        <translation>立即重啟</translation>
     </message>
 </context>
 <context>
