@@ -1,6 +1,8 @@
 // SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
+#include <DFontSizeManager>
 
 #include <QPixmap>
 #include <QColor>
@@ -21,6 +23,8 @@ void BackupWidget::initUI()
     m_iconLabel->setPixmap(QIcon(":/icons/system_backup.svg").pixmap(ICON_SIZE, ICON_SIZE));
     m_titleLabel->setText(tr("Backing up…"));
     m_tipLabel->setText(tr("Backing up the current system, please wait patiently"));
+    DFontSizeManager::instance()->bind(m_titleLabel, DFontSizeManager::T4, QFont::Bold);
+    DFontSizeManager::instance()->bind(m_tipLabel, DFontSizeManager::T6, QFont::Medium);
 }
 
 void BackupWidget::initConnections()
